/**
 * Open SUIT - Simple User Interface Toolkit
 * 
 * Copyright (c) 2009 France Telecom, http://www.francetelecom.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.ow2.opensuit.samples.spring.service;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.ow2.opensuit.samples.spring.to.PersonTO;

/**
* @author Adrien Ruffie / Pierre Smeyers
* @author http://opensuit.ow2.org/
* @version 1.0
*/
public class PersonServiceImpl implements PersonService{

	private final List<PersonTO> persons = new ArrayList<PersonTO>();
	  
    public PersonServiceImpl()
    {
        fillPersonsTOList();
    }

    public List<PersonTO> getAllPersons()
    {
        return persons;
    }

    public PersonTO getPersonByName(final String firstname, final String lastname)
    {
        for(Iterator<PersonTO> iterator = persons.iterator(); iterator.hasNext();)
        {
            PersonTO person = (PersonTO)iterator.next();
            
            if(person.getFirstname().equals(firstname) && person.getLastname().equals(lastname)){
                return person;
            }
        }

        return null;
    }

    public boolean savePerson(final PersonTO person)
    {
        return persons.add(person);
    }

    public List<PersonTO> getPersonsForOrganization(final String organizationUnitName)
    {
        List<PersonTO> organizationStaff = new ArrayList<PersonTO>();
        for(Iterator<PersonTO> iterator = persons.iterator(); iterator.hasNext();)
        {
            PersonTO person = (PersonTO)iterator.next();
            
            if(person.getOrganizationUnitTO() != null && person.getOrganizationUnitTO().getName().equals(organizationUnitName)){
                organizationStaff.add(person);
            }
        }

        return organizationStaff;
    }

    private void fillPersonsTOList()
    {
        persons.add(createPersonTO("Pierre", "Smeyers", "EBM Websourcing"));
        persons.add(createPersonTO("Adrien", "Ruffi\351", "EBM Websourcing"));
    }

    private PersonTO createPersonTO(final String firstname, final String lastname,
    		final String organizationUnitName)
    {
        PersonTO personTO = new PersonTO();
        personTO.setFirstname(firstname);
        personTO.setLastname(lastname);
        personTO.getOrganizationUnitTO().setName(organizationUnitName);
        return personTO;
    }
}
